==> zio-aws-kms_2.13-5.17.130.5-sources.jar: zio/aws/kms/model/GetPublicKeyRequest.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{GrantTokenType, KeyIdType}
import scala.jdk.CollectionConverters._
final case class GetPublicKeyRequest(
    keyId: KeyIdType,
    grantTokens: Option[Iterable[GrantTokenType]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.GetPublicKeyRequest = {
    import GetPublicKeyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
      .builder()
      .keyId(KeyIdType.unwrap(keyId): java.lang.String)
      .optionallyWith(
        grantTokens.map(value =>
          value.map { item =>
            GrantTokenType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.grantTokens)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.GetPublicKeyRequest.ReadOnly =
    zio.aws.kms.model.GetPublicKeyRequest.wrap(buildAwsValue())
}
object GetPublicKeyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.GetPublicKeyRequest = zio.aws.kms.model
      .GetPublicKeyRequest(keyId, grantTokens.map(value => value))
    def keyId: KeyIdType
    def grantTokens: Option[List[GrantTokenType]]
    def getKeyId: ZIO[Any, Nothing, KeyIdType] = ZIO.succeed(keyId)
    def getGrantTokens: ZIO[Any, AwsError, List[GrantTokenType]] =
      AwsError.unwrapOptionField("grantTokens", grantTokens)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
  ) extends zio.aws.kms.model.GetPublicKeyRequest.ReadOnly {
    override val keyId: KeyIdType =
      zio.aws.kms.model.primitives.KeyIdType(impl.keyId())
    override val grantTokens: Option[List[GrantTokenType]] = scala
      .Option(impl.grantTokens())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kms.model.primitives.GrantTokenType(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
  ): zio.aws.kms.model.GetPublicKeyRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kms_2.13-5.17.201.1-sources.jar: zio/aws/kms/model/GetPublicKeyRequest.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{GrantTokenType, KeyIdType}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetPublicKeyRequest(
    keyId: KeyIdType,
    grantTokens: Optional[Iterable[GrantTokenType]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.GetPublicKeyRequest = {
    import GetPublicKeyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
      .builder()
      .keyId(KeyIdType.unwrap(keyId): java.lang.String)
      .optionallyWith(
        grantTokens.map(value =>
          value.map { item =>
            GrantTokenType.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.grantTokens)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.GetPublicKeyRequest.ReadOnly =
    zio.aws.kms.model.GetPublicKeyRequest.wrap(buildAwsValue())
}
object GetPublicKeyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.GetPublicKeyRequest = zio.aws.kms.model
      .GetPublicKeyRequest(keyId, grantTokens.map(value => value))
    def keyId: KeyIdType
    def grantTokens: Optional[List[GrantTokenType]]
    def getKeyId: ZIO[Any, Nothing, KeyIdType] = ZIO.succeed(keyId)
    def getGrantTokens: ZIO[Any, AwsError, List[GrantTokenType]] =
      AwsError.unwrapOptionField("grantTokens", grantTokens)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
  ) extends zio.aws.kms.model.GetPublicKeyRequest.ReadOnly {
    override val keyId: KeyIdType =
      zio.aws.kms.model.primitives.KeyIdType(impl.keyId())
    override val grantTokens: Optional[List[GrantTokenType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.grantTokens())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.kms.model.primitives.GrantTokenType(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.GetPublicKeyRequest
  ): zio.aws.kms.model.GetPublicKeyRequest.ReadOnly = new Wrapper(impl)
}
